@@ -1,13 +1,15 @@
 package Sys::Info::Driver::Windows::Device;
 use strict;
-use vars qw( $VERSION );
+use warnings;
 
-$VERSION = '0.69_10';
+our $VERSION = '0.74_01';
 
 1;
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Sys::Info::Driver::Windows::Device - Base class for Windows device drivers
@@ -18,6 +20,13 @@ Sys::Info::Driver::Windows::Device - Base class for Windows device drivers
 
 =head1 DESCRIPTION
 
+This document describes version C<0.74_01> of C<Sys::Info::Driver::Windows::Device>
+released on C<24 March 2010>.
+
+B<WARNING>: This version of the module is part of a
+developer (beta) release of the distribution and it is
+not suitable for production use.
+
 Base class for Windows device drivers.
 
 =head1 METHODS
@@ -26,16 +35,16 @@ None.
 
 =head1 AUTHOR
 
-Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2006-2009 Burak Grsoy. All rights reserved.
+Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
