@@ -1,10 +1,10 @@
 package Sys::Info::Driver::Windows::OS::Net;
 use strict;
-use vars qw($VERSION);
+use warnings;
 use Win32;
 use Sys::Info::Constants qw( WIN_USER_INFO_LEVEL );
 
-$VERSION = '0.69_10';
+our $VERSION = '0.74_01';
 
 BEGIN {
     if ( ! Win32::IsWin95() ) {
@@ -46,6 +46,8 @@ sub user_logon_server {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Sys::Info::Driver::Windows::OS::Net - A minimal interface to Win32API::Net
@@ -57,6 +59,13 @@ Sys::Info::Driver::Windows::OS::Net - A minimal interface to Win32API::Net
 
 =head1 DESCRIPTION
 
+This document describes version C<0.74_01> of C<Sys::Info::Driver::Windows::OS::Net>
+released on C<24 March 2010>.
+
+B<WARNING>: This version of the module is part of a
+developer (beta) release of the distribution and it is
+not suitable for production use.
+
 A minimal interface to Win32API::Net. If you're under Win9x, all methods
 will return C<undef>.
 
@@ -72,16 +81,16 @@ Returns the logon server of C<USER> if possible.
 
 =head1 AUTHOR
 
-Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2006-2009 Burak Grsoy. All rights reserved.
+Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
